@@ -14,7 +14,6 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#include "radius.h"
 #include "server.h"
 
 static void usage()
@@ -23,7 +22,7 @@ static void usage()
     fprintf(stderr,  "Portslave RADIUS client v%s\tGPL2\n"
   "(c) 1997-1999 Miquel van Smoorenburg, "
   "Dave Cinege, Vesselin Atanasov, et al.\n"
-  "(c) 2000-2001 Russell Coker et al.\n\n"
+  "(c) 2000-2002 Russell Coker et al.\n\n"
   "Usage: portslave port|-\n", PORTSLAVE_VERSION);
     exit(1);
 }
@@ -170,7 +169,18 @@ int main(int argc, char **argv)
         is_ppp = true;
       else
         do_acct = true;
-      
+
+#ifdef FIDO
+/* This is bad - we should support multiple login names for fido - what if
+   you are a NC or RC and you want to use Portslave???  */
+      if(!strcmp(ai.login, lineconf.fidologin))
+      {
+        ai.proto = P_RLOGIN;
+        is_ppp = false;
+        do_acct = true;
+      }
+#endif
+
       if(lineconf.fixedlogin)
         break;
       if(!do_local_or_server_authentication(&ai, is_ppp))
@@ -226,7 +236,7 @@ socket_srv:
       else
         nsyslog(LOG_INFO, "PPP session (%s)", dotted(ai.address));
     break;
-    case P_SSH:
+    case P_SSH1:
       if(!ai.host)
         ai.host = lineconf.host;
       nsyslog(LOG_INFO, "%s/ssh session (%s)", ai.login, dotted(ai.host));
